#
# spec file for package limine
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2025 Marvin Friedrich
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#

Name:           limine
Version:        9.2.2
Release:        1.3
Summary:        Modern, advanced, portable, multiprotocol bootloader and boot manager
License:        BSD-2-Clause
Group:          System/Boot
URL:            https://github.com/limine-bootloader/limine
Source:         %{url}/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  make
BuildRequires:  autoconf
BuildRequires:  nasm
BuildRequires:  mtools
BuildRequires:  clang
BuildRequires:  lld
BuildRequires:  llvm
ExclusiveArch:  x86_64 riscv64 aarch64 loongarch64

%description
Limine is a modern, advanced, portable, multiprotocol bootloader and boot manager,
also used as the reference implementation for the Limine boot protocol.

%prep
%setup -q

%build
%configure --enable-all --docdir=%{_docdir}/%{name} TOOLCHAIN_FOR_TARGET=llvm
%make_build

%install
%make_install

%files
%{_bindir}/limine
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/BOOTAA64.EFI
%{_datadir}/%{name}/BOOTIA32.EFI
%{_datadir}/%{name}/BOOTLOONGARCH64.EFI
%{_datadir}/%{name}/BOOTRISCV64.EFI
%{_datadir}/%{name}/BOOTX64.EFI
%{_datadir}/%{name}/limine-bios-cd.bin
%{_datadir}/%{name}/limine-bios-pxe.bin
%{_datadir}/%{name}/limine-bios.sys
%{_datadir}/%{name}/limine-uefi-cd.bin
%{_mandir}/man1/limine.1.gz
%doc %{_docdir}/%{name}

# Development package
%package -n limine-devel
Summary:        Development files for Limine
BuildArch:      noarch

%description -n limine-devel
C header with Limine structures.

%files -n limine-devel
%{_includedir}/limine.h

%changelog
* Mon Mar 31 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.2.2:
  * Fixes and workarounds in order to make multiboot2 more
    resilient when booting specific kernels such as Xen.
  * Avoid mistakenly allocating more memory than necessary when
    creating the volume index.
* Tue Mar 25 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.2.1:
  * Fix potential buffer overflow bug with stb_image support code.
  * Print the name of unresolved symbols on panic.
  * Dynamically allocate volume index instead of relying on a hard coded
    limit and a fixed allocation.
* Thu Mar 20 2025 Marvin Friedrich <contact@marvinf.com>
- Correct docdir install location
* Thu Mar 20 2025 Marvin Friedrich <contact@marvinf.com>
- Use %%configure macro to build
* Wed Mar 19 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.2.0
* Fri Mar 14 2025 Marvin Friedrich <contact@marvinf.com>
- Use LLVM toolchain to build all targets
* Fri Mar 14 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.1.3
- Remove unused macro
* Mon Feb 17 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.0.0
* Sat Dec  7 2024 Marvin Friedrich <contact@marvinf.com>
- Update to 8.6.0
* Mon Nov 18 2024 Marvin Friedrich <contact@marvinf.com>
- Update to 8.4.0
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Fix EFI_SUFFIX variable
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- EFI bootentry creation
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Make UEFI binary part of seperate package
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Remove config, leave that part to the user
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Modify boot config
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Add default boot config
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Fixed RISC-V EFI filename
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Added EFI building
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Initial update to v7.9.1
